Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1152)

Unified Diff: webkit/plugins/npapi/plugin_list_posix.cc

Issue 13196006: Move path functions from file_util to FilePath object. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: git try Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/glue/webfileutilities_impl.cc ('k') | webkit/plugins/npapi/plugin_list_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/plugins/npapi/plugin_list_posix.cc
diff --git a/webkit/plugins/npapi/plugin_list_posix.cc b/webkit/plugins/npapi/plugin_list_posix.cc
index 175bc4ddc730a0893132f5829b0784d1f88dea32..43d50561cd5bf42ae3d7df64a37a85ed12b0588c 100644
--- a/webkit/plugins/npapi/plugin_list_posix.cc
+++ b/webkit/plugins/npapi/plugin_list_posix.cc
@@ -216,10 +216,9 @@ void PluginList::GetPluginsInDir(
// Java doesn't like being loaded through a symlink, since it uses
// its path to find dependent data files.
// file_util::AbsolutePath calls through to realpath(), which resolves
// symlinks.
- base::FilePath orig_path = path;
- file_util::AbsolutePath(&path);
+ base::FilePath orig_path = base::MakeAbsoluteFilePath(path);
Steve Block 2013/05/07 06:46:28 Shouldn't this be 'path = ...', and orig_path shou
LOG_IF(ERROR, PluginList::DebugPluginLoading())
<< "Resolved " << orig_path.value() << " -> " << path.value();
@@ -216,10 +216,9 @@ void PluginList::GetPluginsInDir(
// Java doesn't like being loaded through a symlink, since it uses
// its path to find dependent data files.
- // file_util::AbsolutePath calls through to realpath(), which resolves
+ // MakeAbsoluteFilePath calls through to realpath(), which resolves
// symlinks.
« no previous file with comments | « webkit/glue/webfileutilities_impl.cc ('k') | webkit/plugins/npapi/plugin_list_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698